<?php
/** Brahui (Bráhuí)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Imdadb
 */

$messages = array(
# Dates
'sunday'        => 'Yakşambe',
'monday'        => 'Duşambe',
'tuesday'       => 'Sişambe',
'wednesday'     => 'Cárşambe',
'thursday'      => 'Pancşambe',
'friday'        => 'Jummá',
'saturday'      => 'Afta',
'sun'           => 'Yakşambe',
'mon'           => 'Duşambe',
'tue'           => 'Sişambe',
'wed'           => 'Cárşambe',
'thu'           => 'Pancşambe',
'fri'           => 'Jummá',
'sat'           => 'Afta',
'january'       => 'Janvarí',
'february'      => 'Farvarí',
'march'         => 'Márc',
'april'         => 'Aprel',
'may_long'      => 'Maí',
'june'          => 'Jún',
'july'          => 'Jaoláí',
'august'        => 'Agast',
'september'     => 'Satumbar',
'october'       => 'Aktúbar',
'november'      => 'Naombar',
'december'      => 'Dasumbar',
'january-gen'   => 'Janvarí',
'february-gen'  => 'Farvarí',
'march-gen'     => 'Márc',
'april-gen'     => 'Aprel',
'may-gen'       => 'Maí',
'june-gen'      => 'Jún',
'july-gen'      => 'Jaoláí',
'august-gen'    => 'Agast',
'september-gen' => 'Satumbar',
'october-gen'   => 'Aktúbar',
'november-gen'  => 'Naombar',
'december-gen'  => 'Dasumbar',
'jan'           => 'Janvarí',
'feb'           => 'Farvarí',
'mar'           => 'Márc',
'apr'           => 'Aprel',
'may'           => 'Maí',
'jun'           => 'Jún',
'jul'           => 'Jaoláí',
'aug'           => 'Agast',
'sep'           => 'Satumbar',
'oct'           => 'Aktúbar',
'nov'           => 'Naombar',
'dec'           => 'Dasumbar',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Xáot|Xáot ák}}',
'category_header'        => 'Xáot "$1" ŧí panna ģák',
'subcategories'          => 'Şefko Xáot ák',
'hidden-categories'      => '{{PLURAL:$1|Aodem á xáot|Aodem á xáot ák}}',
'category-subcat-count'  => '{{PLURAL:$2|Dá xáot aŧí bíra dá şefko-xáot e.|Dá xáot aŧí, kulloí $2 án, đá {{PLURAL:$1|şefko-xáot e|$1 şefko-xáot arer}}.}}',
'category-article-count' => '{{PLURAL:$2|Dá xáot aŧí bíra şefko panna ģák o.|Dá xáot aŧí şefko {{PLURAL:$1|panna|$1 panna}}, kulloí $2 án.}}',
'listingcontinuesabbrev' => 'barjá.',

'about'      => 'Bárav aŧ',
'newwindow'  => '(púskuno darí seŧí malingik)',
'cancel'     => 'Paşomán',
'mytalk'     => 'Kaná ítgap',
'navigation' => 'Kasarşoní',

# Cologne Blue skin
'qbfind' => 'Paŧŧa',

# Vector skin
'vector-action-addsection' => 'Púskun sarhál',
'vector-action-delete'     => 'Mesa',
'vector-action-move'       => 'Surif',
'vector-action-protect'    => 'Rakk',
'vector-view-create'       => 'Biná',
'vector-view-edit'         => 'Radbadal',
'vector-view-history'      => 'Lekav e ur',
'vector-view-view'         => 'Xuán',
'vector-view-viewsource'   => 'Bumpad e ur',
'actions'                  => 'Amal ák',
'namespaces'               => 'Pin-jága ģák',
'variants'                 => 'Badaldroşumk',

'errorpagetitle'   => 'Radí',
'returnto'         => '$1 á aŕseng.',
'tagline'          => '{{SITENAME}} án',
'help'             => 'Ráhşon',
'search'           => 'Paŧŧopol',
'searchbutton'     => 'Paŧŧopol',
'searcharticle'    => 'Ráím',
'history'          => 'Panna ná lekav',
'history_short'    => 'Lekav',
'printableversion' => 'Chapáí droşum',
'permalink'        => 'Pakká gańđ',
'edit'             => 'Radbadal',
'create'           => 'Biná',
'editthispage'     => 'Dá panna ŧí radbadal kar',
'create-this-page' => 'Dá panna e ađđ et',
'delete'           => 'Mesa',
'protect'          => 'Rakk',
'protect_change'   => 'badal kar',
'newpage'          => 'Púskuno panna',
'talkpage'         => 'Dá panna ná bárav aŧ ítgap kabo',
'talkpagelinktext' => 'Ítgap',
'personaltools'    => 'Tená aozár ák',
'talk'             => 'Ítgap',
'views'            => 'Nadára',
'toolbox'          => 'Aozárxána',
'otherlanguages'   => 'Elo bolí teŧí',
'redirectedfrom'   => '($1 án aŕsok)',
'redirectpagesub'  => 'Aŕsengoká panna',
'lastmodifiedat'   => 'Dá panna ŧí guđđíko radbadal $1 ($2) á massus us.',
'jumpto'           => 'Dáng drikka:',
'jumptonavigation' => 'kasarşoní',
'jumptosearch'     => 'paŧŧopol',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} ná bárav aŧ',
'aboutpage'            => 'Project:Bárav',
'copyright'            => 'Mađđí $1 aná rid aŧ rasenging e.',
'copyrightpage'        => '{{ns:project}}:Hakkxuájaí',
'currentevents'        => 'Sáŕí hál',
'currentevents-url'    => 'Project:Sáŕí hál',
'disclaimers'          => 'Dazkaşşík',
'disclaimerpage'       => 'Project:Las dazkaşşí',
'edithelp'             => 'Radbadal ráhşoní',
'edithelppage'         => 'Help:Radbadal',
'helppage'             => 'Help:Ridoband',
'mainpage'             => 'Monpanna',
'mainpage-description' => 'Monpanna',
'portal'               => 'Cágiŕd bundar',
'portal-url'           => 'Project: Cágiŕd bundar',
'privacy'              => 'Rázdárí ráhband',
'privacypage'          => 'Project:Rázdárí ráhband',

'badaccess' => 'Mokal radí',

'retrievedfrom'       => '"$1" án alok',
'youhavenewmessages'  => 'Nekin $1 ($2) are.',
'newmessageslink'     => 'púskuno kulav',
'newmessagesdifflink' => 'guđđíko radbadal',
'editsection'         => 'radbadal',
'editold'             => 'radbadal',
'viewsourceold'       => 'bumpad e ur',
'editlink'            => 'radbadal',
'viewsourcelink'      => 'bumpad e ur',
'editsectionhint'     => 'Vanđ aŧí radbadal: $1',
'toc'                 => 'Ridoband',
'showtoc'             => 'páş',
'hidetoc'             => 'aodem',
'site-rss-feed'       => '$1 RSS serí',
'site-atom-feed'      => '$1 Atom serí',
'page-rss-feed'       => '"$1" RSS serí',
'page-atom-feed'      => '"$1" Atom serí',
'red-link-title'      => '$1 (panna káŧum án aff)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Panna',
'nstab-user'     => 'Kárband ná panna',
'nstab-special'  => 'Xás á panna',
'nstab-project'  => 'Bunkárem panna',
'nstab-image'    => 'Fáil',
'nstab-template' => 'Kálib',
'nstab-category' => 'Xáot',

# General errors
'missing-article'    => 'Cáindárí ambár aŧí panna sená nivişt xanningtav arásiŧ ki xaningosus, "$1" $2 piní á.

Dá geştirí mesingoko panna sená nákára o fark yá lekav ná gańđ aseá ining án marek.

Aga dun aff, to ní software aŧí aeb as xanánus.

Ná minnatvár maron ki dáná itlá e [[Special:ListUsers/sysop|amaldár]] as e kes, o URL e nişán kes.',
'missingarticle-rev' => '(radbadal droşum#: $1)',
'viewsource'         => 'Bumpad e ur',

# Login and logout pages
'yourname'                => 'Kárband pin:',
'yourpassword'            => 'Kilítlaoz:',
'remembermypassword'      => 'Dá darí ŧí kaná pinváxubí e ust á ates (ziát án ziát $1 {{PLURAL:$1|de|de}} akin)',
'login'                   => 'Drustírástí',
'nav-login-createaccount' => 'Drustírástí / pinváxubí',
'userlogin'               => 'Drustírástí / pinváxubí',
'logout'                  => 'Bidar mar',
'userlogout'              => 'Bidar mar',
'nologinlink'             => 'Púskun pinváxubí kar',
'mailmypassword'          => 'Púskuná kilítlaoz e girok ŧapál aŧ mon et',
'loginlanguagelabel'      => 'Bolí: $1',

# Edit page toolbar
'bold_sample'     => 'Zanđ nivişt',
'bold_tip'        => 'Zanđ nivişt',
'italic_sample'   => 'Coŧ nivişt',
'italic_tip'      => 'Coŧ nivişt',
'link_sample'     => 'Gańđ aná sarhál',
'link_tip'        => 'Handí gańđ',
'extlink_sample'  => 'http://www.example.com gańđ aná sarhál',
'extlink_tip'     => 'Darí gańđ (sarlaoz http:// e ust á ates)',
'headline_sample' => 'Sarhál',
'headline_tip'    => 'Şefko sarhál',
'nowiki_sample'   => 'Be-berifok á nivişt áte dáŕe şá',
'nowiki_tip'      => 'Vikí berifing e gírám kar',
'image_tip'       => 'Liccok fáil',
'media_tip'       => 'Fáil ná gańđ',
'sig_tip'         => 'Ná dazrand vaxtŧappo ton avár',
'hr_tip'          => 'Pánádí lík (kazání aŧ kárem aļ)',

# Edit pages
'summary'                          => 'Bungapp:',
'subject'                          => 'Sarhál:',
'minoredit'                        => 'Dá cunko radbadal as e',
'watchthis'                        => 'Dá panna ná xiálí mar',
'savearticle'                      => 'Panna e atíko kar',
'preview'                          => 'Sarí Jác',
'showpreview'                      => 'Sarí jác nişán et',
'showdiff'                         => 'Fark nişán et',
'anoneditwarning'                  => "'''Xiál kes:''' Ní pinváxubí kattanus.
Panna ná radbadal lekav aŧí ná IP pajjár atíko kanningik.",
'summary-preview'                  => 'Bungapp ná sarí jác:',
'newarticle'                       => '(Púskun)',
'newarticletext'                   => "Ní anduno panna sená rand e alkunus ki káŧum án joŕ aff.
Panna ná biná e kanning kin şefko đabbá ŧí likking şurú kar (Pen cáindárí kin [[{{MediaWiki:Helppage}}|ráhşoní panna]] e ur).
Aga dáŕe radínk aŧ bassunus, to ''browser'' ná '''padí''' baŧŧańŕ e xaļ.",
'noarticletext'                    => "Dáiskán dá panna ŧí icc nivişta aff.
Elo panna ģáteŧí [[Special:Search/{{PAGENAME}}|dá sarhál e paŧŧa]],
<span class=\"plainlinks\">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} đek kunoká ''log'' áte paŧŧa],
yá [{{fullurl:{{FULLPAGENAME}}|action=edit}} dá panna ŧí radbadal kar]</span>.",
'noarticletext-nopermission'       => "Dáiskán dá panna ŧí icc nivişta aff.
Elo panna ģáteŧí [[Special:Search/{{PAGENAME}}|dá sarhál e paŧŧa]],
yá <span class=\"plainlinks\">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} đek kunoká ''log'' áte paŧŧa].",
'previewnote'                      => "'''Yát kes ki dá bíra sarí jác ase.'''
Ná radbadal ák deskáne atíko matano.",
'editing'                          => '$1 aŧí radbadal kanning us',
'editingsection'                   => '$1 (vanđ) aŧí radbadal',
'templatesused'                    => 'Dá panna ŧí aloká {{PLURAL:$1|Kálib|Kálib ák}}:',
'templatesusedpreview'             => 'Dá sarí jác aŧí aloká {{PLURAL:$1|Kálib|Kálib ák}}:',
'template-protected'               => '(rakk karok)',
'template-semiprotected'           => '(nem-rakk)',
'hiddencategories'                 => 'Dá panna {{PLURAL:$1|1 aodemo xáot|$1 aodemo xáot}} ná básk ase:',
'permissionserrorstext-withaction' => 'Ne $2 ná mokal aff, oná {{PLURAL:$1|dalíl dáde|dalíl ák dádo}}:',

# History pages
'viewpagelogs'         => 'Dá panna ná hisáb áte ur',
'currentrev-asof'      => '$1 iskán caŧŧ púskuná radbadal droşum',
'revisionasof'         => '$1 á sáŕí badaldroşum',
'previousrevision'     => '← Mutkuná badaldroşum',
'nextrevision'         => 'Púskuná badal droşum →',
'currentrevisionlink'  => 'Caŧŧ púskuná badal droşum',
'cur'                  => 'sáŕí',
'last'                 => 'must',
'history-show-deleted' => 'Bíra mesok',
'histfirst'            => 'Vaxtí á',
'histlast'             => 'Caŧŧ púskuná',

# Revision deletion
'rev-delundel'           => 'páş/aodem',
'revdel-restore'         => 'páşí e badal kar',
'revdel-restore-deleted' => 'mesok badaldroşumk',
'revdel-restore-visible' => 'páş badaldroşumk',

# Merge log
'revertmerge' => 'Jitá',

# Diffs
'history-title' => '$1 aŧí radbadal ná lekav',
'difference'    => '(Badal droşum teŧí fark)',
'lineno'        => 'Lík $1:',
'editundo'      => 'ságí',

# Search results
'searchresults'                    => 'Paŧŧopol ná kaŧŧiá',
'searchresults-title'              => '$1 kin paŧŧopol ná kaŧŧiá',
'searchresulttext'                 => '{{SITENAME}} ŧí paŧŧopol ná bábat cáindárí kin [[{{MediaWiki:Helppage}}|{{int:help}}]] e ur.',
'searchsubtitle'                   => 'Ní \'\'\'[[:$1]]\'\'\' kin paŧpol kares ([[Special:Prefixindex/$1|"$1" án biná maroká ģuŧ panna ģák]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|"$1" ton gańđok ģuŧ panna ģák]])',
'searchsubtitleinvalid'            => "Ní '''$1''' akin paŧŧopol kares",
'notitlematches'                   => 'Dá pin aná icco panna ná sarhál allav',
'notextmatches'                    => 'Icco panna nivişt dá vaŕ aná allav',
'prevn'                            => 'gidrengoká {{PLURAL:$1|$1}}',
'nextn'                            => 'mon aná {{PLURAL:$1|$1}}',
'shown-title'                      => 'Ar panna ģá $1 {{PLURAL:$1|kaŧŧiá|kaŧŧiá}} nişán et',
'viewprevnext'                     => '($1 {{int:pipe-separator}} $2) ($3) e ur',
'searchmenu-new'                   => "'''Dá Vikí ŧí \"[[:\$1]]\" panna ná biná kar!'''",
'searchprofile-articles'           => 'Nivişt panna ģák',
'searchprofile-project'            => 'Ráhşon o bunkárem panna ģák',
'searchprofile-images'             => 'Multimedia',
'searchprofile-everything'         => 'Ar giŕá',
'searchprofile-advanced'           => 'Xúŕt',
'searchprofile-articles-tooltip'   => '$1 ŧí paŧŧa',
'searchprofile-project-tooltip'    => '$1 ŧí paŧŧa',
'searchprofile-images-tooltip'     => 'Fáil átekin paŧŧpol',
'searchprofile-everything-tooltip' => 'Ģuŧŧ nivişt áteŧí paŧŧpol (ítgap ná panna ģáteton avár)',
'search-result-size'               => '$1 ({{PLURAL:$2|1 laoz|$2 laoz}})',
'search-redirect'                  => '(aŕsa $1)',
'search-section'                   => '($1 vanđ)',
'search-suggest'                   => 'Maga dád xuáhása: $1',
'search-interwiki-caption'         => 'Amkár bunkáremk',
'search-interwiki-default'         => '$1 kaŧŧiá:',
'search-interwiki-more'            => '(pen)',
'search-mwsuggest-enabled'         => 'saláh ton',
'search-mwsuggest-disabled'        => 'be saláh',
'searchrelated'                    => 'amrang',
'searchall'                        => 'ģuŧŧ',
'nonefound'                        => "'''Xiáldárí''': Bunyádí vaŕ aŧ bíra giŕás pinjága áteŧí paŧpol marek.

Ģuŧŧ mađđí ŧí paŧpol kin (ítgap panna, kálib, dá-e teton aviŕda) tená just átá avalsar aŧí sarlaoz ''all:'' xaļ, yá bakár pinjága e sarlaoz ná jága ģá xaļ.",
'search-nonefound'                 => 'Just aná icc kaŧŧiá allav',
'powersearch'                      => 'Xúŕt paŧŧopol',
'powersearch-legend'               => 'Xúŕt paŧŧopol',
'powersearch-ns'                   => 'Pin-jága ģáteŧí paŧŧopol:',
'powersearch-redir'                => 'Aŕsoká panna ģátá cirr e nişán et',
'powersearch-field'                => 'Dáŕkin paŧŧopol',

# Preferences page
'preferences'   => 'Gicenk',
'mypreferences' => 'Kaná gicenk',
'yourrealname'  => 'Aslí pin',

# Groups
'group-sysop' => 'Amaldár ák',

'grouppage-sysop' => '{{ns:project}}:Amaldár ák',

# User rights log
'rightslog' => 'Kárband hakk hisáb',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'dá panna ŧí radbadal kar',

# Recent changes
'nchanges'                    => '$1 {{PLURAL:$1|radbadal|radbadal}}',
'recentchanges'               => 'Zút áteaŧ maroká radbadal ák',
'recentchanges-legend'        => 'Zút áteaŧ marok radbadal tekin gicenk',
'recentchanges-label-newpage' => 'Dá radbadal aŧ panna sená biná mass',
'recentchanges-label-minor'   => 'Dá cunko radbadal as e',
'recentchanges-label-bot'     => 'Dá xudkár asená dú án maroko radbadal as e',
'rcnote'                      => "Şefko {{PLURAL:$1|'''1''' radbadal e|guđđíko '''$1''' radbadal áko}}, gidrengoká {{PLURAL:$2|de aŧí|'''$2''' de teŧí}}, $5, $4 ná hisáb aŧ.",
'rcnotefrom'                  => "Şefko raddobadal ák '''$2''' án maroko ('''$1''' iskán páş o)",
'rclistfrom'                  => '$1 án púskuná radbadal áke nişán et',
'rcshowhideminor'             => 'Cunká radbadal áte $1',
'rcshowhidebots'              => 'Boŧ áte $1',
'rcshowhideliu'               => 'Drustírástí kárband áte $1',
'rcshowhideanons'             => 'Bidar kárband áte $1',
'rcshowhidemine'              => 'Kaná radbadal áte $1',
'rclinks'                     => 'Guđđíko $2 de teŧí maroká guđđíko $1 radbadal e nişán et<br />$3',
'diff'                        => 'fark',
'hist'                        => 'lekav',
'hide'                        => 'aodem kar',
'show'                        => 'níşán et',
'minoreditletter'             => 'C',
'newpageletter'               => 'P',
'boteditletter'               => 'x',
'rc-enhanced-expand'          => 'Vaddíko hál e nişán et (JavaScript xuáik)',
'rc-enhanced-hide'            => 'Vaddíko hál e đakka',

# Recent changes linked
'recentchangeslinked'         => 'Amrang á radbadal ák',
'recentchangeslinked-toolbox' => 'Amrang á radbadal ák',
'recentchangeslinked-title'   => '"$1" ná bábat radbadal ák',
'recentchangeslinked-summary' => "Dá amo radbadal átá rid e aráfk ki zút áteaŧ amo panna ģáteŧí massuno aráfk ki xáso panna se án gańđok o (yá xáso xáot asená básk áteton). [[Special:Watchlist|Ná xiálí rid]] aŧí sáŕí panna ģáte '''zanđ nivişt''' aŧ nişán kanningáne.",
'recentchangeslinked-page'    => 'Panna ná pin:',

# Upload
'upload'        => 'Fáil laggif',
'uploadlogpage' => 'Laggifing ná hisáb',
'filedesc'      => 'Bungapp',
'uploadedimage' => '"[[$1]]" laggifingá',

'license'        => 'Muxtárnáma',
'license-header' => 'Muxtárnáma',

# File description page
'file-anchor-link'          => 'Fáil',
'filehist'                  => 'Fáil ná lekav',
'filehist-help'             => 'Táríx/vaxt e xaļ o fáil e amo droşum aŧí ur ki amo vaxt á ass.',
'filehist-revert'           => 'ságí',
'filehist-current'          => 'sáŕí',
'filehist-datetime'         => 'De/Vaxt',
'filehist-thumb'            => 'Cunikfoŧú',
'filehist-thumbtext'        => '$1 íá badal droşum kin cunikfoŧú',
'filehist-user'             => 'Kárband',
'filehist-dimensions'       => 'Bálád',
'filehist-comment'          => 'Darşánxiál',
'imagelinks'                => 'Fáil ná gańđ ák',
'linkstoimage'              => 'Şefko {{PLURAL:$1|panna fáil ton gańđok e|$1 panna ģák fáil ton gańđok o}}:',
'uploadnewversion-linktext' => 'Dá fáil ná púskuno badal droşum as laggif',

# Random page
'randompage' => 'Saŧŧí panna',

# Statistics
'statistics' => 'Hisábkitáb',

# Miscellaneous special pages
'nbytes'        => '$1 {{PLURAL:$1|báiŧ|báiŧ}}',
'nmembers'      => '$1 {{PLURAL:$1|básk|básk}}',
'prefixindex'   => 'Ģuŧŧ panna ģák sarloaz ton',
'newpages'      => 'Púskuná panna ģák',
'move'          => 'Surif',
'movethispage'  => 'Dá panna e surif',
'pager-newer-n' => '{{PLURAL:$1|púskuná 1|púskuná $1}}',
'pager-older-n' => '{{PLURAL:$1|mutkuná 1|mutkuná $1}}',

# Book sources
'booksources'               => 'Kitábí bumpad',
'booksources-search-legend' => 'Kitábí bumpad átekin paŧŧpol',
'booksources-go'            => 'Ráím',

# Special:Log
'log' => 'Lekav',

# Special:AllPages
'allpages'       => 'Ģuŧŧ panna ģák',
'alphaindexline' => '$1 án $2 iskán',
'prevpage'       => 'Mustko panna ($1)',
'allpagesfrom'   => 'Dáŕaŧ biná maroká panna ģáte nişán et:',
'allpagesto'     => 'Dáŕaŧ esar maroká panna ģáte nişán et:',
'allarticles'    => 'Ģuŧŧ panna ģák',
'allpagessubmit' => 'Ráím',

# Special:Categories
'categories' => 'Xáot ák',

# Special:LinkSearch
'linksearch' => 'Darí gańđ',

# Special:Log/newusers
'newuserlogpage' => 'Kárband joŕ kanning ná hisáb',

# Special:ListGroupRights
'listgrouprights-members' => '(básk átá ridoband)',

# Email user
'emailuser' => 'Dá kárband e girokŧapál as mon et',

# Watchlist
'watchlist'         => 'Kaná xiálí rid',
'mywatchlist'       => 'Kaná xiálí rid',
'removedwatchtext'  => 'Panna "[[:$1]]" e [[Special:Watchlist|ná xiálírid]] án kaşşingáne.',
'watch'             => 'Xiálí mar',
'watchthispage'     => 'Dá panna ná xiálí mar',
'unwatch'           => 'Bexiál mar',
'watchlist-details' => 'Ná xiálí rid aŧí {{PLURAL:$1|$1 panna se|$1 panna o}}, ítgap panna ģák hisáb aŧí affas.',
'wlshowlast'        => 'Guđđíko $1 ganŧa $2 de $3 e nişán et',
'watchlist-options' => 'Xiálírid gicenk',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Xiálí manning...',
'unwatching' => 'Bexiál manning...',

# Delete
'deletepage'            => 'Panna e mesa',
'confirmdeletetext'     => 'Ní panna as e oná lekav ton avár mesing aŧí us.
Dá pakk kar ki ní dun kanning xuáisa, dáná pad án poh us, o ní dád [[{{MediaWiki:Policy-url}}|ráhband]] ná vaŕ aŧ kanning us.',
'actioncomplete'        => 'Amal sarjam',
'actionfailed'          => 'Amal besob mass',
'deletedtext'           => '"$1" mesingáne.
Zút áteaŧ mesing átá lekav kin $2 e ur.',
'dellogpage'            => 'Mesing ná hisáb',
'deletecomment'         => 'Dalíl:',
'deleteotherreason'     => 'Elo/pen dalíl:',
'deletereasonotherlist' => 'Elo dalíl',

# Rollback
'rollbacklink' => 'ģuŧŧ e aŕsa',

# Protect
'protectlogpage'              => 'Rakk hisáb',
'protectedarticle'            => '"[[$1]]" rakk mass',
'protectcomment'              => 'Dalíl',
'protect-default'             => 'Ģuŧŧ kárband áte mokal et',
'protect-fallback'            => '"$1" mokal xuáik',
'protect-level-autoconfirmed' => 'Púskuná o bepin á kárband átiá rok xaļ',
'protect-level-sysop'         => 'Bíra Amaldár ák',
'restriction-type'            => 'Mokal:',

# Undelete
'undeletelink'     => 'ur/aŕsa',
'undeleteviewlink' => 'ur',

# Namespace form on various pages
'namespace'      => 'Pin-jága:',
'invert'         => 'Gicen e elo mon kar',
'blanknamespace' => '(Bundar)',

# Contributions
'contributions'       => 'Kárband ná baŕáhík',
'contributions-title' => '$1 kin kárband ná baŕáhík',
'mycontris'           => 'Kaná baŕáhík',
'contribsub2'         => '$1 ($2) kin',
'uctop'               => '(buŕz buŕzko)',
'month'               => 'Dá tú (o must) án:',
'year'                => 'Dá sál (o must) án:',

'sp-contributions-newbies'  => 'Bíra púskuná pinváxub átá baŕáhí te nişán et',
'sp-contributions-blocklog' => 'rok aná hisáb',
'sp-contributions-talk'     => 'ítgap',
'sp-contributions-search'   => 'Baŕáhí kin paŧŧopol',
'sp-contributions-username' => 'IP pajjár yá kárband pin:',
'sp-contributions-submit'   => 'Paŧŧopol',

# What links here
'whatlinkshere'            => 'Dáŕe ant gańđoke',
'whatlinkshere-title'      => '$1 aton gańđok á panna ģák',
'whatlinkshere-page'       => 'Panna:',
'linkshere'                => "Şefko panna ģák '''[[:$1]]''' ton gańđok o:",
'isredirect'               => 'aŕsengoká panna',
'istemplate'               => 'aviŕdaí',
'isimage'                  => 'fáil gańđ',
'whatlinkshere-prev'       => '{{PLURAL:$1|mustko|mustko $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|randíko|randíko $1}}',
'whatlinkshere-links'      => '← gańđ ák',
'whatlinkshere-hideredirs' => '$1 aŕsik',
'whatlinkshere-hidetrans'  => 'aviŕdaí te $1',
'whatlinkshere-hidelinks'  => 'gańđ áte $1',
'whatlinkshere-filters'    => 'Birvek',

# Block/unblock
'blockip'                  => 'Kárband á rok xaļ',
'ipboptions'               => '2 ganŧa:2 hours,1 de:1 day,3 de:3 days,1 afta:1 week,2 afta:2 weeks,1 tú:1 month,3 tú:3 months,6 tú:6 months,1 sál:1 year,be kacc:infinite',
'ipblocklist'              => 'IP pajjár o kárbandpin ák ki rok laggok e iyá tá',
'blocklink'                => 'rok xaļ',
'unblocklink'              => 'rok xalás',
'change-blocklink'         => 'rok aŧí radbadal',
'contribslink'             => 'baŕáhík',
'blocklogpage'             => 'Rok hisáb',
'unblocklogentry'          => '$1 án rok mur kanningá',
'block-log-flags-nocreate' => 'pinváxubí á rok xallingá',

# Move page
'movearticle'    => 'Panna e surif:',
'newtitle'       => 'Púskuná sarhál á:',
'movepagebtn'    => 'Panna e surif',
'pagemovedsub'   => 'Surifing sarsob mass',
'movepage-moved' => '\'\'\'"$1" e "$2"\'\'\' á surifingáne',
'articleexists'  => 'Anná pin aná panna málav án sáŕí e, yá ná tiroká pin ravá aff.
Pen pin as gicen kar.',
'movedto'        => 'dáng surifingá',
'movetalk'       => 'Aviŕda ģá ítgap panna e surif',
'movelogpage'    => 'Surifing ná hisáb',
'movereason'     => 'Dalíl:',
'revertmove'     => 'málav ná',

# Namespace 8 related
'allmessagesname' => 'Pin',

# Thumbnails
'thumbnail-more' => 'Bhallun kar',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Ná kárbandí panna',
'tooltip-pt-mytalk'               => 'Ná ítgap panna',
'tooltip-pt-preferences'          => 'Ná gicenk',
'tooltip-pt-watchlist'            => 'Amo panna ģátá rid aráfteŧí radbadal ná xiálí us',
'tooltip-pt-mycontris'            => 'Ná baŕáhí tá rid',
'tooltip-pt-login'                => 'Drustírástí kes to bház juán e, vale, lázum aff',
'tooltip-pt-logout'               => 'Bidar mar',
'tooltip-ca-talk'                 => 'Niviştánk ná bárav aŧ ítgap',
'tooltip-ca-edit'                 => 'Num dá panna ŧí radbadal kanning kere. Radbadal áte aŧíko kanning án must sarí jác e ta zarúr albo.',
'tooltip-ca-addsection'           => 'Púskuno vanđ asená biná kar',
'tooltip-ca-viewsource'           => 'Dá panna rakk karok e.
Dáná bumpad e unning kesa',
'tooltip-ca-history'              => 'Dá panna ná málav ná şefbuŕz ák',
'tooltip-ca-protect'              => 'Dá panna e rakk kar',
'tooltip-ca-delete'               => 'Dá panna e mesa',
'tooltip-ca-move'                 => 'Dá panna e surif',
'tooltip-ca-watch'                => 'Dá panna e tená xiálí rid aŧí avár kar',
'tooltip-ca-unwatch'              => 'Dá panna e tená xiálí rid án kaşşa',
'tooltip-search'                  => '{{SITENAME}} aŧí paŧŧa',
'tooltip-search-go'               => 'Aga caŧŧ andá pin aná panna are to in iyá ta',
'tooltip-search-fulltext'         => 'Panna ģáteŧí dá laoz áte paŧŧa',
'tooltip-p-logo'                  => 'Monpanna ģá in',
'tooltip-n-mainpage'              => 'Monpanna ģá in',
'tooltip-n-mainpage-description'  => 'Monpanna ģá in',
'tooltip-n-portal'                => 'Kárem ná bábat, ní ant kanning kesa, giŕá te aráŕe paŧŧoí e',
'tooltip-n-currentevents'         => 'Sáŕí sefbuŕz átá bumpadí cáindárí',
'tooltip-n-recentchanges'         => 'Vikí ŧí zút áteaŧ maroká radbadal ák',
'tooltip-n-randompage'            => 'Saŧŧí panna as mal',
'tooltip-n-help'                  => 'Paŧŧing xaning ná jága',
'tooltip-t-whatlinkshere'         => 'Ģuŧ amo vikí panna ģátá rid arfák dáŕe gańđoko',
'tooltip-t-recentchangeslinked'   => 'Dá panna ton gańđoká panna ģáteŧí zút áteaŧ maroká radbadal ák',
'tooltip-feed-rss'                => 'Dá panna kin RSS serí',
'tooltip-feed-atom'               => 'Dá panna kin Atom serí',
'tooltip-t-contributions'         => 'Dá kárband ná baŕáhí tá rid e ur',
'tooltip-t-emailuser'             => 'Dá kárband e girokŧapál as mon et',
'tooltip-t-upload'                => 'Fáil laggif',
'tooltip-t-specialpages'          => 'Ģuŧŧ xás á panna ģátá ridband',
'tooltip-t-print'                 => 'Dá panna ná chapáí droşum',
'tooltip-t-permalink'             => 'Panna ná dá badaldroşum ná pakká gańđ',
'tooltip-ca-nstab-main'           => 'Niviştánk ná panna e ur',
'tooltip-ca-nstab-user'           => 'Kárband ná panna e ur',
'tooltip-ca-nstab-special'        => 'Dá xáso panna as e. Ní dáŧí radbadal kanning kappesa.',
'tooltip-ca-nstab-project'        => 'Bunkárem ná panna e ur',
'tooltip-ca-nstab-image'          => 'Fáil ná panna e ur',
'tooltip-ca-nstab-template'       => 'Kálib e ur',
'tooltip-ca-nstab-category'       => 'Xáot panna e ur',
'tooltip-minoredit'               => 'Dád cunko radbadal as leka',
'tooltip-save'                    => 'Tená radbadal áte atíko kar',
'tooltip-preview'                 => 'Tená radbadal átá sarí jác e aļ. Minnatvár!',
'tooltip-diff'                    => 'Nivişt aŧí tená radbadal áte nişán et',
'tooltip-compareselectedversions' => 'Dá panna ná irá gicen karok radbadal droşum tá niám aŧí fark e ur',
'tooltip-watch'                   => 'Dá panna e tená xiálí rid aŧí avár kar',
'tooltip-rollback'                => '"Ģuŧŧ e aŕsa" án dá panna ŧí guđđíko baŕáhí tirok ná ģuŧŧ radbadal ák asi dakk aŧí aŕsengira.',
'tooltip-undo'                    => '"Aŕsa" e xalling án dá radbadal aŕsengik o sarí jác droşum aŧí radbadal ná darí malingik. Dáŕán bungap aŧí dalíl likking ná vár rasengik.',
'tooltip-summary'                 => 'Guańđo bungapp as aviŕda kar',

# Browsing diffs
'previousdiff' => '← Mutkuná radbadal',
'nextdiff'     => 'Púskuná radbadal',

# Metadata
'metadata-expand'   => 'Vaddíko hál e nişán et',
'metadata-collapse' => 'Vaddíko hál e đakka',

# External editor support
'edit-externally-help' => '(Pen cáindárí kin [//www.mediawiki.org/wiki/Manual:External_editors joŕ kanning ná sarsoj] e ur)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'ģuŧŧ',
'namespacesall' => 'ģuŧŧ',
'monthsall'     => 'ģuŧŧ',

# Watchlist editing tools
'watchlisttools-view' => 'Đek kunoká radbadal áke ur',
'watchlisttools-edit' => 'Xiálí rid e ur o badal kar',
'watchlisttools-raw'  => 'Bekacc á xiálírid aŧí radbadal kar',

# Special:SpecialPages
'specialpages' => 'Xás á panna ģák',

);
